@@ -5,14 +5,14 @@ from pymongo import MongoClient
 from prettytable import PrettyTable
 
 from srsparser import SRSParser
-from srsparser.nlp import get_keywords_pullenti, get_keywords_tf_idf
+from srsparser.nlp import NLProcessor
 
 
 def init_args_parser() -> ap.ArgumentParser:
     parser = ap.ArgumentParser(
         description='A command-line application written in Python that parses unstructured text documents '
                     '(files with .docx extension) with SRS in accordance with GOST standard 34.602-89 and '
-                    'saves the structured results to the MongoDB database.'
+                    'saves the structured results to the MongoDB database'
     )
 
     parser.add_argument(
@@ -21,13 +21,13 @@ def init_args_parser() -> ap.ArgumentParser:
         help='"parse" — analyzes the input documents and saves the parsing '
              'results (as structures) to MongoDB database; '
              '"keywords" — searches for keywords in the content of the document structure, '
-             'which is stored in the resulting MongoDB collection.',
+             'which is stored in the resulting MongoDB collection',
     )
 
     parser.add_argument(
         'mongodb_url',
         type=str,
-        help='MongoDB connection string (with the name of the database).'
+        help='MongoDB connection string (with the name of the database)'
     )
 
     parser.add_argument(
@@ -35,7 +35,7 @@ def init_args_parser() -> ap.ArgumentParser:
         type=str,
         help='name of MongoDB collection with parsing results '
              '(contains software requirements specifications structures '
-             'filled according to the templates of the SRS structures).'
+             'filled according to the templates of the SRS structures)'
     )
 
     parser.add_argument(
@@ -43,7 +43,7 @@ def init_args_parser() -> ap.ArgumentParser:
         '--tmpl-coll',
         dest='tmpl_coll',
         type=str,
-        help='name of MongoDB collection with templates of software requirements specifications structures.'
+        help='name of MongoDB collection with templates of software requirements specifications structures'
     )
 
     parser.add_argument(
@@ -52,7 +52,7 @@ def init_args_parser() -> ap.ArgumentParser:
         dest='tmpl',
         type=str,
         help='template name of software requirements specification structure '
-             'according to which the parsing is performed.'
+             'according to which the parsing is performed'
     )
 
     parser.add_argument(
@@ -60,7 +60,7 @@ def init_args_parser() -> ap.ArgumentParser:
         '--docx-path',
         dest='docx_path',
         type=str,
-        help='path to .docx file containing software requirements specification.'
+        help='path to .docx file containing software requirements specification'
     )
 
     parser.add_argument(
@@ -68,7 +68,7 @@ def init_args_parser() -> ap.ArgumentParser:
         '--docx-name',
         dest='docx_name',
         type=str,
-        help='the name of document that is stored in the resulting collection as structure.'
+        help='the name of document that is stored in the resulting collection as structure'
     )
 
     parser.add_argument(
@@ -76,7 +76,7 @@ def init_args_parser() -> ap.ArgumentParser:
         '--results',
         dest='results',
         action='store_true',
-        help='show a list of document names that are stored in the resulting collection as structures.'
+        help='show a list of document names that are stored in the resulting collection as structures'
     )
 
     return parser
@@ -91,10 +91,11 @@ def main():
 
     results_coll = db[args.results_coll]
     if args.results:
-        print(f'Document names in MongoDB results collection ({args.results_coll}):')
+        print(f'documents in MongoDB results collection ({args.results_coll}):')
         docx_structures = results_coll.find({})
         for structure in docx_structures:
-            print(structure['document_name'])
+            print(f'"{structure["document_name"]}"', end=' ')
+            return
 
     mode = args.mode.lower()
     if mode == 'parse':
@@ -107,7 +108,7 @@ def main():
         document_name = splitext(basename(args.docx_path))[0]
 
         results_coll.insert_one({'document_name': document_name, 'structure': document_structure})
-        print('OK')
+        print('successful! check the results collection')
     elif mode == 'keywords':
         docx_structures = list(results_coll.find({}))
 
@@ -117,13 +118,16 @@ def main():
                 docx_structure_idx = idx
                 break
         if docx_structure_idx < 0:
-            print('there is no such document in the database: ', args.docx_name)
+            print(f'there is no such document in the database with name "{args.docx_name}"')
             return
 
-        tf_idf_keywords = get_keywords_tf_idf(docx_structures, docx_structure_idx)
+        nlp = NLProcessor(init_pullenti=True)
+
+        tf_idf_keywords = nlp.get_keywords_tf_idf(docx_structures, docx_structure_idx)
+        print('tf-idf keywords:', tf_idf_keywords)
 
         docx_structure = docx_structures[docx_structure_idx]['structure']
-        pullenti_keywords = get_keywords_pullenti(docx_structure)
+        pullenti_keywords = nlp.get_keywords_pullenti(docx_structure)
 
         mytable = PrettyTable()
         mytable.add_column('TD-IDF', tf_idf_keywords[:10])
@@ -131,7 +135,7 @@ def main():
 
         print(mytable)
     else:
-        print('the mode does not exist')
+        print('the mode does not exist!')
 
     client.close()
 
